# FritzBox Tray

A system tray application for interacting with FRITZ!Box devices.

![FritzBox Tray Icon](src/fritzbox_tray/resources/ft.ico)

## Features

- Display current external IP address
- Reconnect FRITZ!Box device
- Quit application

## Requirements

- Python 3.6 or higher

## Usage

To start FritzBox Tray, run the following command:

    fritzbox-tray

This will start the application and place an icon in the system tray. Right-clicking on the icon will display a menu with the following options:

 - **Display Current IP Address**: Display a notification with the current external IP address of the FRITZ!Box device
 - **Reconnect**: Terminate and re-establish the Internet connection of the FRITZ!Box device
 - **Quit**: Close the application

## Contribution

Pull requests and issues are welcome.

## License

FritzBox Tray is licensed under the MIT License. See the [LICENSE](link here) file for details.


